class Timeline():
    def __init__(self) -> None:
        self.events = []

    def addEvent(self, event):
        obj = {
            "start_date": {},
            "text": {}
        }
        if(event.url != "" or event.caption != ""):
            obj["media"] = {}
            obj["media"]["url"] = event.url
            obj["media"]["caption"] = event.caption

        obj["start_date"]["day"] = event.getDay()
        obj["start_date"]["month"] = event.getMonth()
        obj["start_date"]["year"] = event.getYear()
        obj["start_date"]["hour"] = event.getHour()
        obj["start_date"]["minute"] = event.getMinute()
        obj["start_date"]["second"] = event.getSecond()
        obj["start_date"]["millisecond"] = 0
        obj["start_date"]["display_date"] = event.getTimestampStr()

        obj["text"]["headline"] = event.headline
        obj["text"]["text"] = "<b>Description:</b><br>" + event.description + "<br><b>Source:</b><br> " + event.source + " <br><b>Evidence:</b><br> " + event.evidence

        self.events.append(obj)


import os
import sys
import csv
import json
import argparse

from examinerview.Controller import Controller
from examinerview.classes.Event import Event
from examinerview.classes.Timeline import Timeline

events = []

def main(args_=None):
    """The main routine."""
    if args_ is None:
        args_ = sys.argv[1:]

    parser = argparse.ArgumentParser()
    parser.add_argument("--data", "-d", type=str, required=True, help="Path to csv file")
    parser.add_argument("--output", "-o", type=str, default=".", help="Path to output dir")
    parser.add_argument("--format", "-f", type=str, default="%Y-%m-%d %H:%M:%S.%f", help="The timestamp format")
    parser.add_argument("--delimiter", "-e", type=str, default=";", help="The delimiter for csv file")
    parser.add_argument("--quotechar", "-q", type=str, default='"', help="The quotechar for csv file")
    args = parser.parse_args()

    ctrl = Controller()

    ctrl.printHeader()

    ctrl.printMessage("        Read data from: " + args.data)

    with open(args.data, 'r', encoding="utf8") as csv_file:

        tl = Timeline()
        reader = csv.reader(csv_file, delimiter=args.delimiter, quotechar=args.quotechar)

        count = 0
        for row in reader:
            if(count > 0):
                event = Event(row[0], row[1], row[2], row[3], row[4], row[5], row[6], args.format)
                events.append(event)
                tl.addEvent(event)
            count = count + 1


    # Create the config file
    jsonPath = os.path.join(args.output, "timeline.json")
    with open(jsonPath, 'w', encoding="utf8") as f:
        json.dump(vars(tl), f, indent=4)

    ctrl.printMessage("Write timeline data to: " + jsonPath)

    # Create the paths
    p = os.path.dirname(__file__)
    tplPath = os.path.join(p, "template", "index.html")
    outputFile = os.path.join(args.output, "examinerview.html")
   
    # Read the template
    html = open(tplPath).read()
    html = html.replace("[DATA_INSERT]", "var data = " + json.dumps(vars(tl)))

    # Write the result
    with open(outputFile, "w") as fp:
        fp.write(html)

    ctrl.printMessage("       Write result to: " + outputFile)
    ctrl.printExecutionTime()

if __name__ == "__main__":
    sys.exit(main())


import datetime

class Event():
    def __init__(self, timestamp, headline, description, url, caption, evidence, source, formatStr) -> None:
        self.timestamp = self.__processTimestamp(timestamp, formatStr)
        self.headline = headline
        self.description = description
        self.url = url
        self.caption = caption
        self.evidence = evidence
        self.source = source

    def __processTimestamp(self, timestamp, formatStr):
        return datetime.datetime.strptime(timestamp, formatStr)

    def getTimestampStr(self):
        return self.timestamp.strftime("%d.%m.%Y, %H:%M:%S")    
    
    def getDay(self):
        return self.timestamp.day

    def getMonth(self):
        return self.timestamp.month

    def getYear(self):
        return self.timestamp.year

    def getHour(self):
        return self.timestamp.hour

    def getMinute(self):
        return self.timestamp.minute

    def getSecond(self):
        return self.timestamp.second

    def getMilliseconds(self):
        return self.timestamp.microsecond